"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importStar(require("react"));
const react_intl_1 = require("react-intl");
const rxjs_1 = require("rxjs");
const styled_components_1 = __importDefault(require("styled-components"));
const react_2 = __importDefault(require("@monaco-editor/react"));
const Field_1 = require("@strapi/design-system/Field");
const design_system_1 = require("@strapi/design-system");
const icons_1 = require("@strapi/icons");
const workers_1 = __importDefault(require("../../utils/workers"));
const languages = [
    'css',
    'dockerfile',
    'graphql',
    'html',
    'javascript',
    'json',
    'kotlin',
    'markdown',
    'mysql',
    'php',
    'plaintext',
    'powerquery',
    'powershell',
    'scss',
    'shell',
    'sql',
    'typescript',
    'xml',
    'yaml',
];
const FullScreenDiv = styled_components_1.default.div `
  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  z-index: 999;
  padding: 45px;
  background: ${({ theme }) => theme.colors.neutral100};
`;
const NormalDiv = styled_components_1.default.div `
  min-height: 35vh;
`;
(0, workers_1.default)();
const CodeEditor = ({ attribute, description, 
// disabled, - todo readonly
error, intlLabel, labelAction, name, onChange, required, value, }) => {
    const { formatMessage } = (0, react_intl_1.useIntl)();
    const languageRegExp = new RegExp('__(.+)__;');
    const isJson = attribute.customField.endsWith('code-editor-json');
    const defaultLanguage = isJson ? 'json' : 'javascript';
    let languageFromValue = value ? value.match(languageRegExp) : null;
    if (languageFromValue && languageFromValue.length > 1) {
        languageFromValue = languageFromValue[1];
    }
    else {
        languageFromValue = null;
    }
    const [language, setLanguage] = (0, react_1.useState)(languageFromValue || defaultLanguage);
    const [editorValue, setEditorValue] = (0, react_1.useState)(value ? value.replace(languageRegExp, '') : '');
    const [subject] = (0, react_1.useState)(new rxjs_1.Subject());
    const [fullScreen, setFullScreen] = (0, react_1.useState)(false);
    // @ts-ignore
    const theme = localStorage.getItem('STRAPI_THEME');
    const handleOnChange = (value) => {
        onChange({ target: { name, value } });
    };
    (0, react_1.useEffect)(() => {
        const subscription = subject.pipe((0, rxjs_1.debounceTime)(1000)).subscribe(handleOnChange);
        return () => {
            subscription.unsubscribe();
        };
    }, []);
    const handleChange = (value) => {
        const valueToSet = value || '';
        setEditorValue(valueToSet);
        subject.next(isJson ? valueToSet : `__${language}__;${valueToSet}`);
    };
    const StyledDiv = fullScreen ? FullScreenDiv : NormalDiv;
    return (react_1.default.createElement(Field_1.Field, { name: name, id: name, error: error, hint: description && formatMessage(description), required: required },
        react_1.default.createElement(StyledDiv, null,
            react_1.default.createElement(design_system_1.Stack, { spacing: 3 },
                react_1.default.createElement(design_system_1.Flex, null,
                    react_1.default.createElement(design_system_1.Flex, { width: "30%", justifyContent: "flex-start" },
                        react_1.default.createElement(Field_1.FieldLabel, { action: labelAction }, formatMessage(intlLabel))),
                    react_1.default.createElement(design_system_1.Flex, { width: "70%", justifyContent: "flex-end" },
                        react_1.default.createElement(design_system_1.Stack, { spacing: 2, horizontal: true },
                            react_1.default.createElement(design_system_1.IconButton, { onClick: () => setFullScreen((prev) => !prev), label: "expand", icon: react_1.default.createElement(design_system_1.Icon, { width: '10rem', height: `10rem`, as: icons_1.Expand }) }),
                            !isJson && (react_1.default.createElement(design_system_1.Select, { id: `${name}-language-select`, label: "", value: language, onChange: setLanguage }, languages.map((lang) => (react_1.default.createElement(design_system_1.Option, { key: lang, value: lang }, lang)))))))),
                react_1.default.createElement(react_1.Suspense, { fallback: react_1.default.createElement(design_system_1.Loader, null, "Loading") },
                    react_1.default.createElement(react_2.default, { height: fullScreen ? '80vh' : '30vh', language: language, loading: react_1.default.createElement(design_system_1.Loader, null, "Loading"), onChange: handleChange, theme: theme === 'dark' ? 'vs-dark' : 'light', value: editorValue })),
                react_1.default.createElement(Field_1.FieldHint, null),
                react_1.default.createElement(Field_1.FieldError, null)))));
};
exports.default = CodeEditor;
//# sourceMappingURL=CodeEditor.js.map